==> dde-file-manager_5.2.18.orig.tar.xz: dde-file-manager-5.2.18/src/dde-dock-plugins/disk-mount/translations/dde-disk-mount-plugin_fi.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="fi" version="2.1">
<context>
    <name>DUMountManager</name>
    <message>
        <source>Authentication timed out</source>
        <translation>Todennus aikakatkaistiin</translation>
    </message>
    <message>
        <source>Disk is busy, cannot unmount now</source>
        <translation>Levy on varattu, ei voi irrottaa</translation>
    </message>
    <message>
        <source>Disk is busy, cannot eject now</source>
        <translation>Levy varattu, ei voi poistaa nyt</translation>
    </message>
    <message>
        <source>The device is busy, cannot eject now</source>
        <translation>Laite on varattu, eikä sitä voi avata</translation>
    </message>
    <message>
        <source>The device is busy, cannot remove now</source>
        <translation>Laite on varattu, eikä sitä voi poistaa</translation>
    </message>
</context>
<context>
    <name>DeepinStorage</name>
    <message>
        <source>%1 Volume</source>
        <translation>%1 Asema</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown</source>
        <translation>Tuntematon</translation>
    </message>
</context>
<context>
    <name>DiskControlWidget</name>
    <message>
        <source>dde-file-manager</source>
        <translation>dde-file-manager-tiedosto-hallinta</translation>
    </message>
    <message>
        <source>The device was not safely removed</source>
        <translation>Laitetta ei poistettu turvallisesti</translation>
    </message>
    <message>
        <source>Click &quot;Safely Remove&quot; and then disconnect it next time</source>
        <translation>Napsauta ensin &quot;Poista turvallisesti&quot; ja irrota se sitten</translation>
    </message>
    <message>
        <source>The device is busy, cannot eject now</source>
        <translation type="vanished">Laite on varattu, eikä sitä voi avata</translation>
    </message>
    <message>
        <source>The device is busy, cannot remove now</source>
        <translation type="vanished">Laite on varattu, eikä sitä voi poistaa</translation>
    </message>
    <message>
        <source>Cannot unmount the device</source>
        <translation>Laitteen irrottaminen ei onnistu</translation>
    </message>
    <message>
        <source>The disk is mounted by user &quot;%1&quot;, you cannot unmount it.</source>
        <translation>Levyä käyttää käyttäjä &quot;%1&quot;, et voi irrottaa sitä.</translation>
    </message>
    <message>
        <source>Cannot find the mounted device</source>
        <translation>Liitettyä laitetta ei löydy</translation>
    </message>
    <message>
        <source>Disks</source>
        <translation>Levyt</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>Levy</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Avaa</translation>
    </message>
    <message>
        <source>Eject all</source>
        <translation>Irroita kaikki</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>The device has been safely removed</source>
        <translation>Laite on poistettu turvallisesti</translation>
    </message>
    <message>
        <source>Access denied</source>
        <translation>Pääsy evätty</translation>
    </message>
    <message>
        <source>You do not have permission to access this folder</source>
        <translation>Sinulla ei ole oikeutta käyttää tätä kansiota</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Vahvista</translation>
    </message>
    <message>
        <source>Scanning the device, stop it?</source>
        <translation>Skannaa laitetta, pysäytä se? </translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Peru</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Seis</translation>
    </message>
</context>
</TS>

==> dde-file-manager_5.6.3.orig.tar.xz: dde-file-manager-5.6.3/src/dde-dock-plugins/disk-mount/translations/dde-disk-mount-plugin_fi.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="fi">
<context>
    <name>DUMountManager</name>
    <message>
        <source>Authentication timed out</source>
        <translation>Todennus aikakatkaistiin</translation>
    </message>
    <message>
        <source>Disk is busy, cannot unmount now</source>
        <translation>Levy on varattu, ei voi irrottaa</translation>
    </message>
    <message>
        <source>Disk is busy, cannot eject now</source>
        <translation>Levy varattu, ei voi poistaa nyt</translation>
    </message>
    <message>
        <source>The device is busy, cannot eject now</source>
        <translation>Laite on varattu, eikä sitä voi avata</translation>
    </message>
    <message>
        <source>The device is busy, cannot remove now</source>
        <translation>Laite on varattu, eikä sitä voi poistaa</translation>
    </message>
</context>
<context>
    <name>DeepinStorage</name>
    <message>
        <source>%1 Volume</source>
        <translation>%1 Asema</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown</source>
        <translation>Tuntematon</translation>
    </message>
</context>
<context>
    <name>DiskControlWidget</name>
    <message>
        <source>dde-file-manager</source>
        <translation>dde-file-manager-tiedosto-hallinta</translation>
    </message>
    <message>
        <source>The device was not safely removed</source>
        <translation>Laitetta ei poistettu turvallisesti</translation>
    </message>
    <message>
        <source>Click &quot;Safely Remove&quot; and then disconnect it next time</source>
        <translation>Napsauta ensin &quot;Poista turvallisesti&quot; ja irrota se sitten</translation>
    </message>
    <message>
        <source>Cannot unmount the device</source>
        <translation>Laitteen irrottaminen ei onnistu</translation>
    </message>
    <message>
        <source>The disk is mounted by user &quot;%1&quot;, you cannot unmount it.</source>
        <translation>Levyä käyttää käyttäjä &quot;%1&quot;, et voi irrottaa sitä.</translation>
    </message>
    <message>
        <source>Cannot find the mounted device</source>
        <translation>Liitettyä laitetta ei löydy</translation>
    </message>
    <message>
        <source>Disks</source>
        <translation>Levyt</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>Levy</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Avaa</translation>
    </message>
    <message>
        <source>Eject all</source>
        <translation>Irroita kaikki</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>The device has been safely removed</source>
        <translation>Laite on poistettu turvallisesti</translation>
    </message>
    <message>
        <source>Access denied</source>
        <translation>Pääsy evätty</translation>
    </message>
    <message>
        <source>You do not have permission to access this folder</source>
        <translation>Sinulla ei ole oikeutta käyttää tätä kansiota</translation>
    </message>
    <message>
        <source>Scanning the device, stop it?</source>
        <translation>Skannaa laitetta, pysäytä se? </translation>
    </message>
    <message>
        <source>Confirm</source>
        <comment>button</comment>
        <translation>Vahvista</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Peruuta</translation>
    </message>
    <message>
        <source>Stop</source>
        <comment>button</comment>
        <translation>Seis</translation>
    </message>
</context>
</TS>
